@@ -50,8 +50,9 @@ def _print_help(parser):
 
 def main():  # pragma: no cover
     """Command Line Hookup."""
-    try:
-        argvhandler(sys.argv[1:])
-    except Exception as exc:  # pylint: disable=W0703
-        print("ERROR: %r" % exc)
-        sys.exit(1)
+    argvhandler(sys.argv[1:])
+    # try:
+    #     argvhandler(sys.argv[1:])
+    # except Exception as exc:  # pylint: disable=W0703
+    #     print("ERROR: %r" % exc)
+    #     sys.exit(1)
