@@ -3,9 +3,9 @@ from .common import (
     add_msgdef_args,
     add_patterns_arg,
     add_read_args,
+    async_load_msgdefs,
     create_ebus,
     disable_stdout_buffering,
-    load_msgdefs,
     print_msg,
 )
 
@@ -28,8 +28,8 @@ def parse_args(subparsers):
 async def _main(args):
     disable_stdout_buffering()
     ebus = create_ebus(args)
-    await load_msgdefs(ebus, args)
+    await async_load_msgdefs(ebus, args)
     msgdefs = ebus.msgdefs.resolve(args.patterns.split(";"))
     print(f"Observing {msgdefs.summary()}")
-    async for msg in ebus.observe(msgdefs=msgdefs, defaultprio=9, setprio=args.prio, ttl=args.ttl):
+    async for msg in ebus.async_observe(msgdefs=msgdefs, defaultprio=9, setprio=args.prio, ttl=args.ttl):
         print_msg(msg)
