@@ -3,9 +3,9 @@ from .common import (
     add_msgdef_args,
     add_patterns_arg,
     add_read_args,
+    async_load_msgdefs,
     create_ebus,
     disable_stdout_buffering,
-    load_msgdefs,
     print_msg,
 )
 
@@ -22,10 +22,10 @@ def parse_args(subparsers):
 async def _main(args):
     disable_stdout_buffering()
     ebus = create_ebus(args)
-    await load_msgdefs(ebus, args)
+    await async_load_msgdefs(ebus, args)
     msgdefs = ebus.msgdefs.resolve(args.patterns.split(";"), filter_=lambda msgdef: msgdef.read or msgdef.update)
     print(f"Reading to {msgdefs.summary()}")
     for msgdef in msgdefs:
         if msgdef.read:
-            msg = await ebus.read(msgdef, defaultprio=9, setprio=args.prio, ttl=args.ttl)
+            msg = await ebus.async_read(msgdef, defaultprio=9, setprio=args.prio, ttl=args.ttl)
             print_msg(msg)
