@@ -3,7 +3,8 @@ import asyncio
 import collections
 import logging
 
-from .connection import CommandError, Connection, ConnectionTimeout
+from .connection import CommandError, Connection
+from .const import OK
 from .msg import filter_msg
 from .msgdecoder import MsgDecoder, UnknownMsgError
 from .msgdefdecoder import decode_msgdef
@@ -68,37 +69,37 @@ class Ebus:
     def __copy__(self):
         return Ebus(self.host, self.port, timeout=self.timeout, scaninterval=self.scaninterval, msgdefs=self.msgdefs)
 
-    async def wait_scancompleted(self):
+    async def async_wait_scancompleted(self):
         """Wait until scan is completed."""
         cnts = []
         while True:
-            cnt = sum([1 async for line in self._request(_CMD_FINDMSGDEFS)])
+            cnt = sum([1 async for line in self._async_request(_CMD_FINDMSGDEFS)])
             cnts.append(cnt)
             if len(cnts) < self.scans or not all(cnt == cnts[-1] for cnt in cnts[-self.scans : -1]):
                 await asyncio.sleep(self.scaninterval)
             else:
                 break
 
-    async def load_msgdefs(self):
+    async def async_load_msgdefs(self):
         """
         Load Message Definitions from EBUSD.
 
         Alias for `load_msgdefcodes` and `decode_msgdefcodes`.
         """
-        await self.load_msgdefcodes()
+        await self.async_load_msgdefcodes()
         self.decode_msgdefcodes()
 
-    async def load_msgdefcodes(self):
+    async def async_load_msgdefcodes(self):
         """Load EBUS Message Definition Codes."""
         _LOGGER.info("load_msgdefcodes()")
         self.msgdefcodes = msgdefcodes = []
-        async for line in self._request(_CMD_FINDMSGDEFS):
+        async for line in self._async_request(_CMD_FINDMSGDEFS):
             line = line.strip()
             if line:
                 try:
-                    msgdef  = decode_msgdef(line)
+                    msgdef = decode_msgdef(line)
                 except ValueError as exc:
-                    _LOGGER.warning(f"Cannot decode message definition '{msgdefcode}' ({exc})")
+                    _LOGGER.warning(f"Cannot decode message definition '{line}' ({exc})")
                 if not msgdef.circuit.startswith("scan"):
                     msgdefcodes.append(line)
 
@@ -117,7 +118,7 @@ class Ebus:
         for msgdef in sorted(msgdefs, key=lambda msgdef: (msgdef.circuit, msgdef.name)):
             self.msgdefs.add(msgdef)
 
-    async def read(self, msgdef, defaultprio=None, setprio=False, ttl=None):
+    async def async_read(self, msgdef, defaultprio=None, setprio=False, ttl=None):
         """
         Read Message.
 
@@ -127,13 +128,15 @@ class Ebus:
         _LOGGER.info(f"read({msgdef!r}, defaultprio={defaultprio!r}, setprio={setprio!r}, ttl={ttl!r})")
         prio = msgdef.prio or defaultprio if setprio else None
         try:
-            lines = tuple([line async for line in self._request("read", msgdef.name, c=msgdef.circuit, p=prio, m=ttl)])
+            lines = tuple(
+                [line async for line in self._async_request("read", msgdef.name, c=msgdef.circuit, p=prio, m=ttl)]
+            )
         except CommandError as exc:
             _LOGGER.warning(f"{msgdef.ident}: {exc!r}")
         else:
             return self.msgdecoder.decode_value(msgdef, lines[0])
 
-    async def write(self, msgdef, value, ttl=0):
+    async def async_write(self, msgdef, value, ttl=0):
         """Write Message."""
         _LOGGER.info(f"write({msgdef!r}, value={value!r}, ttl={ttl!r})")
         if not msgdef.write:
@@ -143,7 +146,9 @@ class Ebus:
             # Read
             if not msgdef.read:
                 raise ValueError(f"Message is not read-modify-writable '{msgdef}'")
-            readline = tuple([line async for line in self._request("read", msgdef.name, c=msgdef.circuit, m=ttl)])[0]
+            readline = tuple(
+                [line async for line in self._async_request("read", msgdef.name, c=msgdef.circuit, m=ttl)]
+            )[0]
             values = readline.split(";")
             # Modify
             for fielddef in msgdef.fields:
@@ -152,13 +157,13 @@ class Ebus:
         else:
             values = [str(fielddef.type_.encode(value)) for fielddef in msgdef.fields]
         # Write
-        async for _ in self._request("write", msgdef.name, ";".join(values), c=msgdef.circuit, check=True):
+        async for _ in self._async_request("write", msgdef.name, ";".join(values), c=msgdef.circuit, check=True):
             pass
 
-    async def listen(self, msgdefs=None):
+    async def async_listen(self, msgdefs=None):
         """Listen to EBUSD, decode and yield."""
         _LOGGER.info(f"listen(msgdefs={msgdefs!r})")
-        async for line in self._request("listen", infinite=True):
+        async for line in self._async_request("listen", infinite=True):
             if line == "listen started":
                 continue
             msg = self._decode_line(line)
@@ -167,7 +172,7 @@ class Ebus:
             if msg:
                 yield msg
 
-    async def observe(self, msgdefs=None, defaultprio=None, setprio=False, ttl=None):
+    async def async_observe(self, msgdefs=None, defaultprio=None, setprio=False, ttl=None):
         """
         Observe.
 
@@ -182,7 +187,7 @@ class Ebus:
         # read all
         for msgdef in msgdefs:
             if msgdef.read:
-                msg = await self.read(msgdef, defaultprio=defaultprio, setprio=setprio, ttl=ttl)
+                msg = await self.async_read(msgdef, defaultprio=defaultprio, setprio=setprio, ttl=ttl)
                 if msg.valid:
                     msg = filter_msg(msg, msgdefs)
                 if msg.valid:
@@ -192,7 +197,7 @@ class Ebus:
                 data[msgdef] = None
 
         # find new values (which got updated while we where reading)
-        async for line in self._request("find -d"):
+        async for line in self._async_request("find -d"):
             msg = self._decode_line(line)
             if msg:
                 msg = filter_msg(msg, msgdefs)
@@ -201,41 +206,51 @@ class Ebus:
                 data[msg.msgdef] = msg
 
         # listen
-        async for msg in self.listen(msgdefs=msgdefs):
+        async for msg in self.async_listen(msgdefs=msgdefs):
             yield msg
 
-    async def get_state(self):
+    async def async_get_state(self):
         """Return state string."""
         _LOGGER.info("get_state()")
         try:
-            lines = tuple([line async for line in self._request("state")])
+            lines = tuple([line async for line in self._async_request("state")])
             state = lines[0].split(",")[0]
             if state == "signal acquired":
-                return "ok"
+                return OK
             else:
                 return state
-        except ConnectionTimeout:
+        except Exception:  # pylint: disable=W0703
             return "no ebusd connection"
 
-    async def is_online(self):
+    async def async_is_online(self):
         """Return if we are online."""
-        state = await self.get_state()
-        return state == "ok"
+        state = await self.async_get_state()
+        return state == OK
 
-    async def cmd(self, cmd, infinite=False, check=False):
+    async def async_get_info(self):
+        """Return info dict."""
+        _LOGGER.info("get_info()")
+        info = {}
+        async for line in self._async_request("info"):
+            if line:
+                name, value = line.split(":", 1)
+                info[name.strip()] = value.strip()
+        return info
+
+    async def async_cmd(self, cmd, infinite=False, check=False):
         """Send `cmd` to EBUSD and Receive Response."""
         _LOGGER.info(f"cmd({cmd!r}, infinite={infinite!r}, check={check!r})")
-        await self.connection.write(cmd)
-        async for line in self.connection.readlines(infinite=infinite, check=check):
+        await self.connection.async_write(cmd)
+        async for line in self.connection.async_readlines(infinite=infinite, check=check):
             yield line
 
-    async def _request(self, cmd, *args, infinite=False, check=False, **kwargs):
+    async def _async_request(self, cmd, *args, infinite=False, check=False, **kwargs):
         """Assemble request, send and readlines."""
         parts = [cmd]
         parts += [f"-{option} {value}" for option, value in kwargs.items() if value is not None]
         parts += [str(arg) for arg in args]
-        await self.connection.write(" ".join(parts))
-        async for line in self.connection.readlines(infinite=infinite, check=check):
+        await self.connection.async_write(" ".join(parts))
+        async for line in self.connection.async_readlines(infinite=infinite, check=check):
             yield line
 
     def _decode_line(self, line):
